import { BehaviorSubject, Subject } from 'rxjs';
import { takeUntil, filter } from 'rxjs/operators';
import { Router, ActivationEnd, ActivatedRoute } from '@angular/router';
import { Injectable, Component, Input, ViewChild, Directive, TemplateRef, NgModule, defineInjectable } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxBootstrapNavbarService {
    constructor() {
        this._templates = new Map();
        this._templates$ = new BehaviorSubject({ brand: null, left: null, right: null });
    }
    /**
     * @return {?}
     */
    get templates$() {
        return this._templates$.asObservable();
    }
    /**
     * @param {?} entry
     * @return {?}
     */
    setTemplate(entry) {
        this._templates.set(entry.route, entry);
        this._update(entry.context);
    }
    /**
     * @param {?} entry
     * @return {?}
     */
    removeTemplate(entry) {
        this._templates.delete(entry.route);
        this._update(entry.context);
    }
    /**
     * @private
     * @param {?} context
     * @return {?}
     */
    _update(context) {
        /** @type {?} */
        const entries = [];
        this._templates.forEach((v) => entries.push(v));
        /** @type {?} */
        const contextEntries = entries.filter(e => e.context === context);
        contextEntries.sort((a, b) => a.priority - b.priority);
        /** @type {?} */
        const newEntries = Object.assign({}, this._templates$.value);
        newEntries[context] = contextEntries[contextEntries.length - 1] || null;
        this._templates$.next(newEntries);
    }
}
NgxBootstrapNavbarService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
NgxBootstrapNavbarService.ctorParameters = () => [];
/** @nocollapse */ NgxBootstrapNavbarService.ngInjectableDef = defineInjectable({ factory: function NgxBootstrapNavbarService_Factory() { return new NgxBootstrapNavbarService(); }, token: NgxBootstrapNavbarService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxBootstrapNavbarComponent {
    /**
     * @param {?} _service
     * @param {?} _router
     */
    constructor(_service, _router) {
        this._service = _service;
        this._router = _router;
        this._ngUnsubscribe = new Subject();
        this.navbarClass = 'navbar navbar-expand-lg navbar-dark bg-primary';
        this.brandTemplateRef = null;
        this.leftTemplateRef = null;
        this.rightTemplateRef = null;
    }
    /**
     * @return {?}
     */
    get service() {
        return this._service;
    }
    /**
     * @return {?}
     */
    get $collapse() {
        return jQuery(this.collapseElementRef.nativeElement);
    }
    /**
     * @return {?}
     */
    get routerEvents() {
        return (/** @type {?} */ (this._router.events
            .pipe(filter(e => e instanceof ActivationEnd))));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.id = `ngx-bs-navbar-${++NgxBootstrapNavbarComponent.count}`;
        this.service.templates$
            .pipe(takeUntil(this._ngUnsubscribe))
            .subscribe(val => {
            this.brandTemplateRef = val.brand ? val.brand.templateRef : null;
            this.leftTemplateRef = val.left ? val.left.templateRef : null;
            this.rightTemplateRef = val.right ? val.right.templateRef : null;
        });
        this.$collapse.collapse({ toggle: false });
        this.routerEvents
            .pipe(takeUntil(this._ngUnsubscribe))
            .subscribe(() => this.$collapse.collapse('hide'));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._ngUnsubscribe.next();
        this._ngUnsubscribe.complete();
    }
    /**
     * @return {?}
     */
    toggle() {
        this.$collapse.collapse('toggle');
    }
}
NgxBootstrapNavbarComponent.count = 0;
NgxBootstrapNavbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-bootstrap-navbar',
                template: `
  <nav [attr.class]="navbarClass">
    <ng-container *ngTemplateOutlet="brandTemplateRef"></ng-container>
    <button
      class="navbar-toggler"
      type="button"
      [attr.aria-controls]="id + '-collapse'"
      aria-expanded="false"
      aria-label="Toggle navigation"
      (click)="toggle()">
      <span class="navbar-toggler-icon"></span>
    </button>
    <div class="collapse navbar-collapse" #collapse [attr.id]="id + '-collapse'">
      <div class="mr-auto">
        <ng-container *ngTemplateOutlet="leftTemplateRef"></ng-container>
      </div>
      <div class="ml-auto">
        <ng-container *ngTemplateOutlet="rightTemplateRef"></ng-container>
      </div>
    </div>
  </nav>
  `
            }] }
];
/** @nocollapse */
NgxBootstrapNavbarComponent.ctorParameters = () => [
    { type: NgxBootstrapNavbarService },
    { type: Router }
];
NgxBootstrapNavbarComponent.propDecorators = {
    collapseElementRef: [{ type: ViewChild, args: ['collapse',] }],
    navbarClass: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const NgxBsNavbarContext = {
    brand: 'brand',
    left: 'left',
    right: 'right',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxBootstrapNavbarContentDirective {
    /**
     * @param {?} _service
     * @param {?} _route
     * @param {?} _templateRef
     */
    constructor(_service, _route, _templateRef) {
        this._service = _service;
        this._route = _route;
        this._templateRef = _templateRef;
    }
    /**
     * @return {?}
     */
    get service() {
        return this._service;
    }
    /**
     * @return {?}
     */
    get route() {
        return this._route.snapshot;
    }
    /**
     * @return {?}
     */
    get templateRef() {
        return this._templateRef;
    }
    /**
     * @return {?}
     */
    get context() {
        return this.ngxBsNavbarContent;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        let current = this.route;
        /** @type {?} */
        let routeCount = 0;
        while (current) {
            routeCount++;
            current = current.parent;
        }
        this.priority = routeCount;
        this.service.setTemplate(this);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.service.removeTemplate(this);
    }
}
NgxBootstrapNavbarContentDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngxBsNavbarContent]'
            },] }
];
/** @nocollapse */
NgxBootstrapNavbarContentDirective.ctorParameters = () => [
    { type: NgxBootstrapNavbarService },
    { type: ActivatedRoute },
    { type: TemplateRef }
];
NgxBootstrapNavbarContentDirective.propDecorators = {
    ngxBsNavbarContent: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxBootstrapNavbarModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: NgxBootstrapNavbarModule,
            providers: [NgxBootstrapNavbarService]
        };
    }
}
NgxBootstrapNavbarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxBootstrapNavbarComponent, NgxBootstrapNavbarContentDirective],
                imports: [
                    CommonModule
                ],
                exports: [NgxBootstrapNavbarComponent, NgxBootstrapNavbarContentDirective]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxBootstrapNavbarService, NgxBootstrapNavbarComponent, NgxBootstrapNavbarContentDirective, NgxBsNavbarContext, NgxBootstrapNavbarModule };

//# sourceMappingURL=nowzoo-ngx-bootstrap-navbar.js.map